#!/bin/sh

# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24
# 
#  (c) Copyright IBM Corp. 2006, 2007.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************
# 
# ************************************************************************
#  Update Monitor Server 6.0.2.1 to iFix5 level
# ************************************************************************

# define fixpack-specific variables
MON_FIXPACK_LEVEL=iFix5
MON_FIXPACK=6.0.2.1-WBI-MONITOR-$MON_FIXPACK_LEVEL
MON_FIXPACK_INST=./$MON_FIXPACK.install
MON_FIXPACK_BACKUP=$MON_FIXPACK_INST/backups/monsrv
MON_FIXPACK_STAMP=$MON_FIXPACK.version

# define input prompts       
MON_PROMPT="Type the path to the WebSphere Business Monitor installation directory"
WPS_PROMPT="Type the path to the Process Server installation directory"
PROFILE_PROMPT="Type the path to the Process Server profile directory"
DMGR_PROMPT="Is this update running on an ND Deployment Manager? Type y or n"
SERVER_PROMPT="Type the server name"

# define default values for standalone server and deployment manager
MON_HOME=/usr/IBM/WebSphere/Monitor
WAS_HOME1=/usr/IBM/WebSphere/ProcServer
WAS_PROFILE_NAME=wbmonitor
WAS_SERVER_NAME=server1
DMGR_PROFILE_NAME=dmgr
DMGR_SERVER_NAME=dmgr


# ************************************************************************
# Begin function definitions
# ************************************************************************

# ************************************************************************
# Back up file being replaced, then copy in new one
# Don't copy file that doesn't exist in target
# ************************************************************************
backupandreplace ()
{
  echo $0: $*
  replacefile=${1##*/}
  if [ -f $2/$replacefile ]
  then
    if [ ! -d $MON_FIXPACK_BACKUP/$3 ]
    then
      mkdir -p $MON_FIXPACK_BACKUP/$3
      checkCmdErr $?
    fi

    if [ ! -f $MON_FIXPACK_BACKUP/$3/$replacefile ]
    then
      cp -f $2/$replacefile $MON_FIXPACK_BACKUP/$3 >> $MY_LOG 2>&1
      checkCmdErr $?
    else
      echo "Backup already created for $replacefile in $MON_FIXPACK_BACKUP/$3, not overwriting"
      logecho "Backup already created for $replacefile in $MON_FIXPACK_BACKUP/$3, not overwriting" >> $MY_LOG
    fi

    cp -f $1 $2 >> $MY_LOG 2>&1
    checkCmdErr $?
  fi
}

# ************************************************************************
# Process a single plugin directory; back up directory being replaced,
# then copy in new one
# Don't copy directory that doesn't exist in target
# ************************************************************************
backupandreplaceplugins ()
{
  echo $0: $*
  plugindir=${1##*/}
  if [ -d $2/$plugindir ]
  then
    if [ ! -d $MON_FIXPACK_BACKUP/$3/$plugindir ]
    then
      if [ ! -d $MON_FIXPACK_BACKUP/$3 ]
      then
        mkdir -p $MON_FIXPACK_BACKUP/$3
      fi
      cp -f -R $2/$plugindir $MON_FIXPACK_BACKUP/$3 >> $MY_LOG 2>&1
      checkCmdErr $?
    else
      echo "Backup already created for $plugindir in $MON_FIXPACK_BACKUP/$3, not overwriting"
      logecho "Backup already created for $plugindir in $MON_FIXPACK_BACKUP/$3, not overwriting"
    fi

    cp -f -R $1 $2 >> $MY_LOG 2>&1
    checkCmdErr $?
  fi
}

# ************************************************************************
# Write messages to log file
# ************************************************************************
logecho ()
{
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
  echo $1 >> $MY_LOG
  echo "++++++++++++++++++++++++++++++++++++++++++++++++++++++++" >> $MY_LOG
  date +%T >> $MY_LOG
  return 0
}

# ************************************************************************
# Copy iFix version file ("stamp") and backups to Monitor home
# ************************************************************************
copystampandbackups ()
{
  echo Copying backups and version info to Monitor home.
  logecho "Copying backups and version info to Monitor home."

  cp -f ./version/*.* $MON_FIXPACK_INST >> $MY_LOG 2>&1

  MON_FIXPACK_DIR=$MON_HOME/update
  if [ ! -d $MON_FIXPACK_DIR ]
  then
    mkdir -p $MON_FIXPACK_DIR
  fi
  cp -f -R $MON_FIXPACK_INST $MON_FIXPACK_DIR >> $MY_LOG 2>&1
}

# ************************************************************************
# Copy log file to Monitor home
# ************************************************************************
copylog ()
{
   if [ "$MON_HOME" != "" ]
   then
      MON_LOG_DIR=$MON_HOME/update/$MON_FIXPACK_INST/logs
      if [ ! -d $MON_LOG_DIR ] 
      then 
         mkdir -p $MON_LOG_DIR
      fi 
      cp -f $MY_LOG $MON_LOG_DIR
   fi
}

# ************************************************************************
# Check return code from command execution
# ************************************************************************
checkCmdErr ()
{
  if [ $1 -ne 0 ]
  then 
    echo Error: command failed, return code = $1
    logecho "+++ Error: command failed, return code = $1"
    failed 8
  fi
  return 0
}

# ************************************************************************
# Print failure message and get out 
# ************************************************************************
failed()
{
    echo Update failed! 
    logecho "Update failed"
    copylog
    exit $1
}
# ************************************************************************
# End function definitions
# ************************************************************************


# ************************************************************************
# Begin main code 
# ************************************************************************

# set up logs directory
MY_DIR=`pwd`
if [ ! -e  $MY_DIR/logs ] 
then 
   mkdir -p $MY_DIR/logs
fi 
MY_LOG=$MY_DIR/logs/monsrv.log

echo Start Monitor Server 6.0.2.1 $MON_FIXPACK_LEVEL update...
logecho "Start Monitor Server 6.0.2.1 $MON_FIXPACK_LEVEL update..."

# ask if DMgr is being updated       
DMGR_UPGRADE=x
while [ $DMGR_UPGRADE = x ]
do
   echo $DMGR_PROMPT : 
   read RESPONSE
   if [ "$RESPONSE" = "y" ] 
   then
      DMGR_UPGRADE=$RESPONSE
      PROFILE_NAME1=$DMGR_PROFILE_NAME
      SERVER_NAME1=$DMGR_SERVER_NAME
   fi
   if [ "$RESPONSE" = "n" ] 
   then
      DMGR_UPGRADE=$RESPONSE
      PROFILE_NAME1=$WAS_PROFILE_NAME
      SERVER_NAME1=$WAS_SERVER_NAME
   fi
done


# get Monitor home
echo $MON_PROMPT [enter=$MON_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   MON_HOME=$RESPONSE
fi
if [ ! -d $MON_HOME ]
then 
   echo +++ Error: Monitor home - $MON_HOME does NOT exist!
   logecho "+++ Error: Monitor home - $MON_HOME does NOT exist!"
   MON_HOME=
   failed 8
fi

# get WAS home dir 
echo $WPS_PROMPT [enter=$WAS_HOME1 ]: 
read input
if [ "$input" != "" ]
then
   WAS_HOME1=$input
fi

if [ ! -d $WAS_HOME1 ]
then 
   echo +++ Error: Process Server home - $WAS_HOME1 does NOT exist!
   logecho "+++ Error: Process Server home - $WAS_HOME1 does NOT exist!"
   failed 8
fi

# get profile dir                  
WAS_PROFILE_HOME=$WAS_HOME1/profiles/$PROFILE_NAME1
echo $PROFILE_PROMPT [enter=$WAS_PROFILE_HOME ]: 
read input
if [ "$input" != "" ]
then
   WAS_PROFILE_HOME=$input
fi

if [ ! -d $WAS_PROFILE_HOME ]
then 
   echo +++ Error: Profile home - $WAS_PROFILE_HOME does NOT exist!
   logecho "+++ Error: Profile home - $WAS_PROFILE_HOME does NOT exist!"
   failed 8
fi

# get server name                  
echo $SERVER_PROMPT [enter=$SERVER_NAME1 ]: 
read input
if [ "$input" != "" ]
then
   SERVER_NAME1=$input
fi

# setupCmdLine will set WAS_CELL and WAS_NODE
if [ -e ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh ]
then
   . ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh >> $MY_LOG 2>&1
else
   echo +++ Error: ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh does NOT exist!
   logecho "+++ Error: ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh does NOT exist!"
   failed 8
fi
# verify that the server exists
SERVER_HOME=$WAS_PROFILE_HOME/config/cells/$WAS_CELL/nodes/$WAS_NODE/servers/$SERVER_NAME1
if [ ! -d $SERVER_HOME ]
then 
   echo +++ Error: Server home - $SERVER_HOME does NOT exist!
   logecho "+++ Error: Server home - $SERVER_HOME does NOT exist!"
   failed 8
fi

# ************************************************************************
# Look for stamp for this level in Monitor home; if found and backup
# directory for this component is present then this level is already
# installed for this component
# ************************************************************************
MON_FIXPACK_DIR=$MON_HOME/update/$MON_FIXPACK_INST
if [ -f $MON_FIXPACK_DIR/$MON_FIXPACK_STAMP ]
then
  if [ -d $MON_FIXPACK_DIR/backups/monsrv ]
  then
    echo +++ Error: This fixpack level \($MON_FIXPACK\) has already been installed for the Monitor server.
    logecho "+++ Error: This fixpack level \($MON_FIXPACK\) has already been installed for the Monitor server."
    failed 8
  fi
fi

# ************************************************************************
# Create directory for backing up files to be replaced
# ************************************************************************
echo backup directory is $MON_FIXPACK_BACKUP
if [ ! -d $MON_FIXPACK_BACKUP ]
then
  echo "Creating backup directory"
  mkdir -p $MON_FIXPACK_BACKUP >> $MY_LOG 2>&1
fi
checkCmdErr $?

# ************************************************************************
# copy jar files (KQ - restore)
# ************************************************************************
#echo Stop server $SERVER_NAME1 ...
#logecho "Stop server $SERVER_NAME1 ..."
#. ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh
#sh ${WAS_PROFILE_HOME}/bin/stopServer.sh $SERVER_NAME1 >> $MY_LOG 2>&1

# ************************************************************************
# copy server jar files
# ************************************************************************
# Back up existing files to be replaced and replace
for jarfile in ./jars/*
do
	backupandreplace $jarfile ${WAS_HOME1}/lib jars
done
checkCmdErr $?

# ************************************************************************
# copy jar files for MME plugins
# ************************************************************************
# Back up existing files (plugin directories) to be replaced and replace
for plugindir in ./mme/plugins/*
do 
	backupandreplaceplugins $plugindir ${WAS_HOME1}/deploytool/itp/plugins plugins
done
checkCmdErr $?

# ************************************************************************
# copy our stamp and backups to the Monitor home directory
# ************************************************************************
copystampandbackups

# ************************************************************************
# Restart the server
# ************************************************************************
echo Start server $SERVER_NAME1 ...
logecho "Start server $SERVER_NAME1 ..."
sh ${WAS_PROFILE_HOME}/bin/startServer.sh $SERVER_NAME1 >> $MY_LOG 2>&1
checkCmdErr $?

echo Update finished.
logecho "Update finished."
copylog
exit 0
